@@ -162,7 +162,7 @@ public final class JdbcDatabaseManager extends AbstractDatabaseManager {
     private final class Reconnector extends Log4jThread {
 
         private final CountDownLatch latch = new CountDownLatch(1);
-        private volatile boolean shutdown = false;
+        private volatile boolean shutdown;
 
         private Reconnector() {
             super("JdbcDatabaseManager-Reconnector");
@@ -245,7 +245,6 @@ public final class JdbcDatabaseManager extends AbstractDatabaseManager {
         private ResultSetColumnMetaData(final String schemaName, final String catalogName, final String tableName,
                 final String name, final String label, final int displaySize, final int type, final String typeName,
                 final String className, final int precision, final int scale) {
-            super();
             this.schemaName = schemaName;
             this.catalogName = catalogName;
             this.tableName = tableName;
@@ -360,14 +359,14 @@ public final class JdbcDatabaseManager extends AbstractDatabaseManager {
                         colMapping);
                 i++;
             }
-            if (data.columnConfigs != null) {
-                for (final ColumnConfig colConfig : data.columnConfigs) {
-                    final String columnName = colConfig.getColumnName();
-                    appendColumnName(i, columnName, sb);
-                    logger().trace(messagePattern, sqlVerb, colConfig.getClass().getSimpleName(), i, columnName,
-                            colConfig);
-                    i++;
-                }
+        }
+        if (data.columnConfigs != null) {
+            for (final ColumnConfig colConfig : data.columnConfigs) {
+                final String columnName = colConfig.getColumnName();
+                appendColumnName(i, columnName, sb);
+                logger().trace(messagePattern, sqlVerb, colConfig.getClass().getSimpleName(), i, columnName,
+                        colConfig);
+                i++;
             }
         }
     }
@@ -390,11 +389,11 @@ public final class JdbcDatabaseManager extends AbstractDatabaseManager {
      */
     @Deprecated
     public static JdbcDatabaseManager getJDBCDatabaseManager(final String name, final int bufferSize,
-            final ConnectionSource connectionSource, final String tableName, final ColumnConfig[] columnConfigs) {
+        final ConnectionSource connectionSource, final String tableName, final ColumnConfig[] columnConfigs) {
         return getManager(
-                name, new FactoryData(bufferSize, null, connectionSource, tableName, columnConfigs,
-                        new ColumnMapping[0], false, AbstractDatabaseAppender.DEFAULT_RECONNECT_INTERVAL_MILLIS, true),
-                getFactory());
+            name, new FactoryData(bufferSize, null, connectionSource, tableName, columnConfigs,
+                ColumnMapping.EMPTY_ARRAY, false, AbstractDatabaseAppender.DEFAULT_RECONNECT_INTERVAL_MILLIS, true),
+            getFactory());
     }
 
     /**
@@ -747,7 +746,20 @@ public final class JdbcDatabaseManager extends AbstractDatabaseManager {
      * Sets the given Object in the prepared statement. The value is truncated if needed.
      */
     private void setStatementObject(final int j, final String nameKey, final Object value) throws SQLException {
-        statement.setObject(j, truncate(nameKey, value));
+        if (statement == null) {
+            throw new AppenderLoggingException("Cannot set a value when the PreparedStatement is null.");
+        }
+        if (value == null) {
+            if (columnMetaData == null) {
+                throw new AppenderLoggingException("Cannot set a value when the column metadata is null.");
+            }
+            // [LOG4J2-2762] [JDBC] MS-SQL Server JDBC driver throws SQLServerException when
+            // inserting a null value for a VARBINARY column.
+            // Calling setNull() instead of setObject() for null values fixes [LOG4J2-2762].
+            this.statement.setNull(j, columnMetaData.get(nameKey).getType());
+        } else {
+            statement.setObject(j, truncate(nameKey, value));
+        }
     }
 
     @Override
@@ -818,13 +830,7 @@ public final class JdbcDatabaseManager extends AbstractDatabaseManager {
                             } else {
                                 final Object value = TypeConverters.convert(layout.toSerializable(event),
                                         mapping.getType(), null);
-                                if (value == null) {
-                                    // TODO We might need to always initialize the columnMetaData to specify the
-                                    // type.
-                                    this.statement.setNull(j++, Types.NULL);
-                                } else {
-                                    setStatementObject(j++, mapping.getNameKey(), value);
-                                }
+                                setStatementObject(j++, mapping.getNameKey(), value);
                             }
                         }
                     }
@@ -850,10 +856,15 @@ public final class JdbcDatabaseManager extends AbstractDatabaseManager {
             }
 
             if (isBuffered() && this.isBatchSupported) {
+                logger().debug("addBatch for {}", this.statement);
                 this.statement.addBatch();
-            } else if (this.statement.executeUpdate() == 0) {
-                throw new AppenderLoggingException(
-                        "No records inserted in database table for log event in JDBC manager [%s].", fieldsToString());
+            } else {
+                final int executeUpdate = this.statement.executeUpdate();
+                logger().debug("executeUpdate = {} for {}", executeUpdate, this.statement);
+                if (executeUpdate == 0) {
+                    throw new AppenderLoggingException(
+                            "No records inserted in database table for log event in JDBC manager [%s].", fieldsToString());
+                }
             }
         } catch (final SQLException e) {
             throw new DbAppenderLoggingException(e, "Failed to insert record for log event in JDBC manager: %s [%s]", e,
